@@ -1,15 +1,11 @@
 <?php
 /**
- * Prepare the test setup.
- */
-require_once dirname(__FILE__) . '/Autoload.php';
-
-/**
+ * Copyright 2010-2013 Horde LLC (http://www.horde.org/)
+ *
  * @author     Jan Schneider <jan@horde.org>
  * @category   Horde
  * @package    Share
  * @subpackage UnitTests
- * @copyright  2010 Horde LLC (http://www.horde.org/)
  * @license    http://www.horde.org/licenses/lgpl21 LGPL 2.1
  */
 class Horde_Share_Test_Base extends Horde_Test_Case
@@ -582,6 +578,13 @@ class Horde_Share_Test_Base extends Horde_Test_Case
         }
     }
 
+    public function renameShare()
+    {
+        self::$share->renameShare(self::$shares['janeshare'], 'joeshare');
+        $this->assertArrayNotHasKey('janeshare', self::$share->listAllShares());
+        $this->assertArrayHasKey('joeshare', self::$share->listAllShares());
+    }
+
     public function callback($share)
     {
         $share->setShareOb(new Horde_Support_Stub());
@@ -607,4 +610,4 @@ class Horde_Share_Test_Base extends Horde_Test_Case
     {
     }
 
-}
\ No newline at end of file
+}
